// TOP PLATE FOR MILL Z-AXIS S/TEPPER
$fa = 0.5;
$fs = 0.1;

pleng       = 175;  // X size of plate
pwide       = 125;	// Y
pthick      = 4;	// Z

stepperX    = 35;               // stepper motor centre
stepperY    = 35;          		// 
stepperbolt = 5;                // M5
slotL       = 5;                // slot length

// the belt length is the fixed distance here
belt        = 98.14;			// belt length between centres
offsetY     = 50;
offsetX     = sqrt(belt*belt - offsetY*offsetY);

screwX      = stepperX + offsetX; // screw centre
screwY      = stepperY + offsetY;
screwbolt   = 8;                // M8

// define a slot made of two circles and a rectange enlarged in the X direction
// NB: the centre of the slot is the base position so the slot is +/- on that.
module slot(diam, widthX){
    union(){
        translate([-widthX/2,0,0])
            cylinder(h=pthick+2, d=diam);
        translate([widthX/2,0,0])
            cylinder(h=pthick+2, d=diam);
        translate([-widthX/2, -diam/2, 0])
            cube([widthX, diam, pthick+2]);
    }
}

difference(){
    cube([pleng, pwide, pthick]);
    union(){
        // do stepper motor holes
        translate([stepperX, stepperY, -1]){
            union(){
                slot(diam=39, widthX=slotL);
                hx = 47.41/2;           // bolt spacing
                translate([-hx, -hx, 0])
                    slot(diam=stepperbolt, widthX=slotL);
                translate([hx, -hx, 0])
                    slot(diam=stepperbolt, widthX=slotL);
                translate([hx, hx, 0])
                    slot(diam=stepperbolt, widthX=slotL);
                translate([-hx, hx, 0])
                    slot(diam=stepperbolt, widthX=slotL);
            }
        }
        // do the Z screw thread holes
        translate([screwX, screwY, -1]){
            union(){
                frontW = 78.0;
                rearW  = 63.8;
                frontOffset = 27.0;
                front2rear  = 50.5;
                cylinder(h=pthick+2, d=40);
                translate([-frontW/2, frontOffset, 0])
                    cylinder(h=pthick+2, d=screwbolt);
                translate([frontW/2, frontOffset, 0])
                    cylinder(h=pthick+2,d=screwbolt);
                translate([-rearW/2, frontOffset-front2rear, 0])
                    cylinder(h=pthick+2, d=screwbolt);
                translate([rearW/2, frontOffset-front2rear, 0])
                    cylinder(h=pthick+2, d=screwbolt);
            }
        }
		// mounting bolt hole (M6 tap)
		translate([pleng-75, 35, -0.01])
			cylinder(h=pthick+0.02, d=5);
		// cable out gland
		translate([pleng-18, 18, -0.01])
			cylinder(h=pthick+0.02, d=20);
		// cable in grommet
		translate([80, 30, -0.01])
			cylinder(h=pthick+0.02, d=6.5);
		//connector screws
		translate([pleng-51, 30+15, -0.01])
			cylinder(d=4, h=pthick+0.02);
		translate([pleng-51, 30-15, -0.01])
			cylinder(d=4, h=pthick+0.02);
    }
}
